// Copyright (c) 2017, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

library editex.interface;

import 'package:eqlib/latex.dart';

/// EdiTeX Template Type
/// Special template types that are recognized by the internal system.
enum EdiTeXTT { frac, sub, sup, eq, add, subtract, other }

/// Template data
class EdiTeXTemplate {
  /// Unique template ID.
  final int id;

  /// Human readable label.
  final String label;

  /// LaTeX template
  final LaTeXTemplate template;

  /// Parsable template
  /// This template is passed to the expression parser. It contains `$i` where
  /// parameters should be inserted.
  final String parsableTemplate;

  /// Type annotation
  final EdiTeXTT type;

  EdiTeXTemplate(this.id, this.label, this.template, this.parsableTemplate,
      [this.type = EdiTeXTT.other]);

  EdiTeXTemplate clone() =>
      new EdiTeXTemplate(id, label, template, parsableTemplate);

  int get parameterCount => template.parameterCount;
}

/// Interface functions
abstract class EdiTeXInterface {
  /// Lookup template by ID.
  EdiTeXTemplate getTemplate(int id);

  /// Get templates that match the given keyword, in order of most relevant to
  /// less relevant. The editor will show the suggestions to the user.
  List<EdiTeXTemplate> lookupKeyword(String keyword);

  /// Get single template associated to the given character. This template is
  /// inserted right away. This is how operators and parentheses work.
  EdiTeXTemplate lookupCharacter(String char);
}
