// Copyright (c) 2017, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by a MIT-style license
// that can be found in the LICENSE file.

@JS('katex')
library katex;

import 'dart:html';
import 'package:js/js.dart';

export 'dart:js' show allowInterop;

/// Call katex.render with a TeX expression and a DOM element to render into.
///
/// If KaTeX can't parse the expression, it throws a katex.ParseError error.
@JS()
external void render(String expression, Element element,
    [RenderingOptions options]);

/// Generates an HTML string of the rendered math;
@JS()
external String renderToString(String expression, [RenderingOptions options]);

/// You can provide an object of options as the last argument to [render] and
/// [renderToString].
@anonymous
@JS()
class RenderingOptions {
  external factory RenderingOptions(
      {bool displayMode, String errorColor, bool throwOnError});

  /// If false the math will be rendered in inline mode.
  ///
  /// If true the math will be rendered in display mode, which will put
  /// the math in display style (so \int and \sum are large, for example),
  /// and will center the math on the page on its own line.
  /// (default: false)
  external bool get displayMode;
  external set displayMode(bool displayMode);

  /// A color string given in the format "#XXX" or "#XXXXXX".
  ///
  /// This option determines the color which unsupported commands are rendered
  /// in. (default: #cc0000)
  external String get errorColor;
  external set familyName(String errorColor);

  /// If true, KaTeX will throw a ParseError when it encounters an unsupported
  /// command.
  ///
  /// If false, KaTeX will render the unsupported command as text in the color
  /// given by [errorColor]. (default: true)
  external bool get throwOnError;
  external set throwOnError(bool throwOnError);
}
